package betterquesting.handlers;

import betterquesting.api.api.QuestingAPI;
import betterquesting.api.client.gui.misc.INeedsRefresh;
import betterquesting.api.events.BQLivingUpdateEvent;
import betterquesting.api.events.DatabaseEvent;
import betterquesting.api.events.QuestEvent;
import betterquesting.api.placeholders.FluidPlaceholder;
import betterquesting.api.properties.NativeProps;
import betterquesting.api.questing.IQuest;
import betterquesting.api.questing.party.IParty;
import betterquesting.api.storage.BQ_Settings;
import betterquesting.api.utils.BigItemStack;
import betterquesting.api2.cache.QuestCache;
import betterquesting.api2.client.gui.GuiScreenTest;
import betterquesting.api2.client.gui.themes.gui_args.GArgsNone;
import betterquesting.api2.client.gui.themes.presets.PresetGUIs;
import betterquesting.api2.storage.DBEntry;
import betterquesting.client.BQ_Keybindings;
import betterquesting.client.gui2.GuiHome;
import betterquesting.client.themes.ThemeRegistry;
import betterquesting.core.BetterQuesting;
import betterquesting.network.handlers.NetBulkSync;
import betterquesting.network.handlers.NetNameSync;
import betterquesting.network.handlers.NetNotices;
import betterquesting.network.handlers.NetQuestSync;
import betterquesting.questing.QuestDatabase;
import betterquesting.questing.party.PartyInvitations;
import betterquesting.questing.party.PartyManager;
import betterquesting.storage.LifeDatabase;
import betterquesting.storage.NameCache;
import betterquesting.storage.QuestSettings;
import com.google.common.util.concurrent.Futures;
import com.google.common.util.concurrent.ListenableFuture;
import com.google.common.util.concurrent.ListenableFutureTask;
import cpw.mods.fml.client.event.ConfigChangedEvent;
import cpw.mods.fml.common.eventhandler.SubscribeEvent;
import cpw.mods.fml.common.gameevent.InputEvent;
import cpw.mods.fml.common.gameevent.PlayerEvent;
import cpw.mods.fml.common.gameevent.TickEvent;
import cpw.mods.fml.relauncher.Side;
import cpw.mods.fml.relauncher.SideOnly;
import java.util.ArrayDeque;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.UUID;
import java.util.concurrent.Callable;
import java.util.concurrent.Executors;
import java.util.concurrent.FutureTask;
import net.minecraft.client.Minecraft;
import net.minecraft.entity.player.EntityPlayer;
import net.minecraft.entity.player.EntityPlayerMP;
import net.minecraft.item.ItemStack;
import net.minecraft.nbt.NBTTagCompound;
import net.minecraft.server.MinecraftServer;
import net.minecraft.server.integrated.IntegratedServer;
import net.minecraft.server.management.UserListBansEntry;
import net.minecraft.util.ChatComponentText;
import net.minecraft.util.IIcon;
import net.minecraftforge.client.event.TextureStitchEvent;
import net.minecraftforge.common.MinecraftForge;
import net.minecraftforge.event.CommandEvent;
import net.minecraftforge.event.entity.EntityJoinWorldEvent;
import net.minecraftforge.event.entity.living.LivingDeathEvent;
import net.minecraftforge.event.entity.player.PlayerEvent;
import net.minecraftforge.event.world.WorldEvent;
import org.apache.commons.lang3.Validate;

/* loaded from: betterquesting_handlers.jar:betterquesting/handlers/EventHandler.class */
public class EventHandler {
    private final ArrayDeque<EntityPlayerMP> opQueue = new ArrayDeque<>();
    private boolean openToLAN = false;
    public static final EventHandler INSTANCE = new EventHandler();
    private static final ArrayDeque<FutureTask> serverTasks = new ArrayDeque<>();
    private static Thread serverThread = null;

    @SubscribeEvent
    @SideOnly(Side.CLIENT)
    public void onKey(InputEvent.KeyInputEvent event) {
        Minecraft mc = Minecraft.func_71410_x();
        if (BQ_Keybindings.openQuests.func_151468_f()) {
            if (mc.field_71439_g.func_70093_af() && mc.field_71439_g.func_70005_c_().equalsIgnoreCase("Funwayguy")) {
                mc.func_147108_a(new GuiScreenTest(mc.field_71462_r));
            } else if (BQ_Settings.useBookmark && GuiHome.bookmark != null) {
                mc.func_147108_a(GuiHome.bookmark);
            } else {
                mc.func_147108_a(ThemeRegistry.INSTANCE.getGui(PresetGUIs.HOME, GArgsNone.NONE));
            }
        }
    }

    @SubscribeEvent
    public void onEntityJoin(EntityJoinWorldEvent event) {
        if ((event.entity instanceof EntityPlayer) && event.entity.getExtendedProperties(QuestCache.LOC_QUEST_CACHE.toString()) == null) {
            event.entity.registerExtendedProperties(QuestCache.LOC_QUEST_CACHE.toString(), new QuestCache());
        }
    }

    @SubscribeEvent
    public void onPlayerClone(PlayerEvent.Clone event) {
        QuestCache oCache = event.original.getExtendedProperties(QuestCache.LOC_QUEST_CACHE.toString());
        QuestCache nCache = event.entityPlayer.getExtendedProperties(QuestCache.LOC_QUEST_CACHE.toString());
        if (oCache != null && nCache != null) {
            NBTTagCompound tmp = new NBTTagCompound();
            oCache.saveNBTData(tmp);
            nCache.loadNBTData(tmp);
        }
    }

    @SubscribeEvent
    public void onLivingUpdate(BQLivingUpdateEvent event) {
        if (!event.entityLiving.field_70170_p.field_72995_K && (event.entityLiving instanceof EntityPlayerMP) && event.entityLiving.field_70173_aa % 20 == 0) {
            EntityPlayerMP player = event.entityLiving;
            QuestCache qc = player.getExtendedProperties(QuestCache.LOC_QUEST_CACHE.toString());
            boolean editMode = ((Boolean) QuestSettings.INSTANCE.getProperty(NativeProps.EDIT_MODE)).booleanValue();
            if (qc == null) {
                return;
            }
            List<DBEntry<IQuest>> activeQuests = QuestDatabase.INSTANCE.bulkLookup(qc.getActiveQuests());
            List<DBEntry<IQuest>> pendingAutoClaims = QuestDatabase.INSTANCE.bulkLookup(qc.getPendingAutoClaims());
            QuestCache.QResetTime[] pendingResets = qc.getScheduledResets();
            UUID uuid = QuestingAPI.getQuestingUUID(player);
            boolean refreshCache = false;
            if (!editMode && player.field_70173_aa % 60 == 0) {
                List<Integer> com = new ArrayList<>();
                for (DBEntry<IQuest> quest : activeQuests) {
                    if (((IQuest) quest.getValue()).isUnlocked(uuid)) {
                        if (((IQuest) quest.getValue()).canSubmit(player)) {
                            ((IQuest) quest.getValue()).update(player);
                        }
                        if (((IQuest) quest.getValue()).isComplete(uuid) && !((IQuest) quest.getValue()).canSubmit(player)) {
                            refreshCache = true;
                            qc.markQuestDirty(quest.getID());
                            com.add(Integer.valueOf(quest.getID()));
                            if (!((Boolean) ((IQuest) quest.getValue()).getProperty(NativeProps.SILENT)).booleanValue()) {
                                postPresetNotice((IQuest) quest.getValue(), player, 2);
                            }
                        }
                    }
                }
                MinecraftForge.EVENT_BUS.post(new QuestEvent(QuestEvent.Type.COMPLETED, uuid, com));
            }
            if (!editMode && MinecraftServer.func_71276_C() != null) {
                List<Integer> res = new ArrayList<>();
                long totalTime = System.currentTimeMillis();
                for (QuestCache.QResetTime rTime : pendingResets) {
                    IQuest entry = (IQuest) QuestDatabase.INSTANCE.getValue(rTime.questID);
                    if (totalTime < rTime.time || entry.canSubmit(player)) {
                        break;
                    }
                    if (((Boolean) entry.getProperty(NativeProps.GLOBAL)).booleanValue()) {
                        entry.resetUser((UUID) null, false);
                    } else {
                        entry.resetUser(uuid, false);
                    }
                    refreshCache = true;
                    qc.markQuestDirty(rTime.questID);
                    res.add(Integer.valueOf(rTime.questID));
                    if (!((Boolean) entry.getProperty(NativeProps.SILENT)).booleanValue()) {
                        postPresetNotice(entry, player, 1);
                    }
                }
                MinecraftForge.EVENT_BUS.post(new QuestEvent(QuestEvent.Type.RESET, uuid, res));
            }
            if (!editMode) {
                for (DBEntry<IQuest> entry2 : pendingAutoClaims) {
                    if (((IQuest) entry2.getValue()).canClaim(player)) {
                        ((IQuest) entry2.getValue()).claimReward(player);
                        refreshCache = true;
                        qc.markQuestDirty(entry2.getID());
                    }
                }
            }
            if (refreshCache || player.field_70173_aa % 200 == 0) {
                qc.updateCache(player);
            }
            if (qc.getDirtyQuests().length > 0) {
                NetQuestSync.sendSync(player, qc.getDirtyQuests(), false, true);
            }
            qc.cleanAllQuests();
        }
    }

    private static void postPresetNotice(IQuest quest, EntityPlayer player, int preset) {
        if (player instanceof EntityPlayerMP) {
            ItemStack icon = ((BigItemStack) quest.getProperty(NativeProps.ICON)).getBaseStack();
            String mainText = "";
            String subText = (String) quest.getProperty(NativeProps.NAME);
            String sound = "";
            switch (preset) {
                case 0:
                    mainText = "betterquesting.notice.unlock";
                    sound = (String) quest.getProperty(NativeProps.SOUND_UNLOCK);
                    break;
                case 1:
                    mainText = "betterquesting.notice.update";
                    sound = (String) quest.getProperty(NativeProps.SOUND_UPDATE);
                    break;
                case 2:
                    mainText = "betterquesting.notice.complete";
                    sound = (String) quest.getProperty(NativeProps.SOUND_COMPLETE);
                    break;
            }
            NetNotices.sendNotice(((Boolean) quest.getProperty(NativeProps.GLOBAL)).booleanValue() ? null : new EntityPlayerMP[]{(EntityPlayerMP) player}, icon, mainText, subText, sound);
        }
    }

    @SubscribeEvent
    public void onConfigChanged(ConfigChangedEvent.OnConfigChangedEvent event) {
        if (event.modID.equals("betterquesting")) {
            ConfigHandler.config.save();
            ConfigHandler.initConfigs();
        }
    }

    @SubscribeEvent
    public void onWorldSave(WorldEvent.Save event) {
        if (!event.world.field_72995_K && BQ_Settings.curWorldDir != null && event.world.field_73011_w.field_76574_g == 0) {
            SaveLoadHandler.INSTANCE.saveDatabases();
        }
    }

    @SubscribeEvent
    public void onPlayerJoin(PlayerEvent.PlayerLoggedInEvent event) {
        if (event.player.field_70170_p.field_72995_K || MinecraftServer.func_71276_C() == null || !(event.player instanceof EntityPlayerMP)) {
            return;
        }
        EntityPlayerMP mpPlayer = event.player;
        if (BetterQuesting.proxy.isClient() && !MinecraftServer.func_71276_C().func_71262_S() && MinecraftServer.func_71276_C().func_71214_G().equals(event.player.func_146103_bH().getName())) {
            NameCache.INSTANCE.updateName(mpPlayer);
        } else {
            NetBulkSync.sendReset(mpPlayer, true, true);
        }
    }

    @SubscribeEvent
    public void onPlayerRespawn(PlayerEvent.PlayerRespawnEvent event) {
        if (((Boolean) QuestSettings.INSTANCE.getProperty(NativeProps.HARDCORE)).booleanValue() && (event.player instanceof EntityPlayerMP) && !event.player.field_71136_j) {
            EntityPlayerMP mpPlayer = event.player;
            int lives = LifeDatabase.INSTANCE.getLives(QuestingAPI.getQuestingUUID(mpPlayer));
            if (lives <= 0) {
                MinecraftServer server = MinecraftServer.func_71276_C();
                if (server == null) {
                    return;
                }
                if (server.func_71264_H() && mpPlayer.func_70005_c_().equals(server.func_71214_G())) {
                    mpPlayer.field_71135_a.func_147360_c("You have died. Game over, man, it's game over!");
                    server.func_71272_O();
                    return;
                } else {
                    UserListBansEntry userlistbansentry = new UserListBansEntry(mpPlayer.func_146103_bH(), (Date) null, "(You just lost the game)", (Date) null, "Death in Hardcore");
                    server.func_71203_ab().func_152608_h().func_152687_a(userlistbansentry);
                    mpPlayer.field_71135_a.func_147360_c("You have died. Game over, man, it's game over!");
                    return;
                }
            }
            if (lives == 1) {
                mpPlayer.func_146105_b(new ChatComponentText("This is your last life!"));
            } else {
                mpPlayer.func_146105_b(new ChatComponentText(lives + " lives remaining!"));
            }
        }
    }

    @SubscribeEvent
    public void onLivingDeath(LivingDeathEvent event) {
        if (!event.entityLiving.field_70170_p.field_72995_K && ((Boolean) QuestSettings.INSTANCE.getProperty(NativeProps.HARDCORE)).booleanValue() && (event.entityLiving instanceof EntityPlayer)) {
            UUID uuid = QuestingAPI.getQuestingUUID(event.entityLiving);
            int lives = LifeDatabase.INSTANCE.getLives(uuid);
            LifeDatabase.INSTANCE.setLives(uuid, lives - 1);
        }
    }

    @SubscribeEvent
    @SideOnly(Side.CLIENT)
    public void onTextureStitch(TextureStitchEvent.Pre event) {
        if (event.map.func_130086_a() == 0) {
            IIcon icon = event.map.func_94245_a("betterquesting:fluid_placeholder");
            FluidPlaceholder.fluidPlaceholder.setIcons(icon);
        }
    }

    @SubscribeEvent
    @SideOnly(Side.CLIENT)
    public void onDataUpdated(DatabaseEvent.Update event) {
        INeedsRefresh iNeedsRefresh = Minecraft.func_71410_x().field_71462_r;
        if (iNeedsRefresh instanceof INeedsRefresh) {
            Minecraft func_71410_x = Minecraft.func_71410_x();
            INeedsRefresh iNeedsRefresh2 = iNeedsRefresh;
            iNeedsRefresh2.getClass();
            func_71410_x.func_152343_a(Executors.callable(iNeedsRefresh2::refreshGui));
        }
    }

    @SubscribeEvent
    public void onCommand(CommandEvent event) {
        EntityPlayerMP playerMP;
        MinecraftServer server = MinecraftServer.func_71276_C();
        if (server != null) {
            if ((event.command.func_71517_b().equalsIgnoreCase("op") || event.command.func_71517_b().equalsIgnoreCase("deop")) && (playerMP = server.func_71203_ab().func_152612_a(event.parameters[0])) != null) {
                this.opQueue.add(playerMP);
            }
        }
    }

    public static <T> ListenableFuture<T> scheduleServerTask(Callable<T> task) {
        Validate.notNull(task);
        if (Thread.currentThread() != serverThread) {
            FutureTask create = ListenableFutureTask.create(task);
            synchronized (serverTasks) {
                serverTasks.add(create);
            }
            return create;
        }
        try {
            return Futures.immediateFuture(task.call());
        } catch (Exception exception) {
            return Futures.immediateFailedCheckedFuture(exception);
        }
    }

    @SubscribeEvent
    public void onServerTick(TickEvent.ServerTickEvent event) {
        if (event.phase == TickEvent.Phase.START) {
            if (serverThread == null) {
                serverThread = Thread.currentThread();
            }
            synchronized (serverTasks) {
                while (!serverTasks.isEmpty()) {
                    serverTasks.poll().run();
                }
            }
            return;
        }
        IntegratedServer func_71276_C = MinecraftServer.func_71276_C();
        if (!func_71276_C.func_71262_S()) {
            boolean tmp = this.openToLAN;
            this.openToLAN = (func_71276_C instanceof IntegratedServer) && func_71276_C.func_71344_c();
            if (this.openToLAN && !tmp) {
                this.opQueue.addAll(func_71276_C.func_71203_ab().field_72404_b);
            }
        } else if (!this.openToLAN) {
            this.openToLAN = true;
        }
        while (!this.opQueue.isEmpty()) {
            EntityPlayerMP playerMP = this.opQueue.poll();
            if (playerMP != null && NameCache.INSTANCE.updateName(playerMP)) {
                DBEntry<IParty> party = PartyManager.INSTANCE.getParty(QuestingAPI.getQuestingUUID(playerMP));
                if (party != null) {
                    NetNameSync.quickSync((EntityPlayerMP) null, party.getID());
                } else {
                    NetNameSync.sendNames(new EntityPlayerMP[]{playerMP}, new UUID[]{QuestingAPI.getQuestingUUID(playerMP)}, (String[]) null);
                }
            }
        }
        if (func_71276_C.func_71259_af() % 60 == 0) {
            PartyInvitations.INSTANCE.cleanExpired();
        }
        for (EntityPlayerMP player : func_71276_C.func_71203_ab().field_72404_b) {
            MinecraftForge.EVENT_BUS.post(new BQLivingUpdateEvent(player));
        }
    }
}
